# Generated by Django 5.0.9 on 2024-11-11 11:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wbcommission", "0007_remove_commission_unique_crm_recipient_account_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="commission",
            options={
                "ordering": ("order",),
                "permissions": (("administrate_commission", "Can administrate Commission"),),
                "verbose_name": "Commission",
                "verbose_name_plural": "Commissions",
            },
        ),
        migrations.AlterField(
            model_name="commission",
            name="order",
            field=models.PositiveIntegerField(db_index=True, editable=False, verbose_name="order"),
        ),
    ]
